package com.my.config.dbConfig;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.jdbc.support.rowset.SqlRowSet;
import org.springframework.stereotype.Component;
import org.springframework.jdbc.support.GeneratedKeyHolder;
import org.springframework.jdbc.support.KeyHolder;

import com.my.model.CommonPage;
import com.my.model.ResponseParams;
import com.my.utils.MyUtils;

@Component
public class JdbcTemplateDao {

	@Resource
	private MyJdbcTemplate myJdbcTemplate;
	
	/**
	 * 根据语句查询，并筛选结果 1、替换字段映射名为原字段名
	 */
	public ResponseParams queryBySQL(
			String querySQL,
			String queryCountSQL,
			CommonPage page) {
		List<Map<String, Object>> resultList = new ArrayList<Map<String, Object>>();
		if(MyUtils.isNotNull(querySQL)) {
			SqlRowSet rowSet = myJdbcTemplate.queryForRowSet(querySQL);
			List<String> fieldNameList = Arrays.asList(rowSet.getMetaData().getColumnNames());
			while (rowSet.next()) {
				Map<String, Object> map = new LinkedHashMap<String, Object>();
				for (int y = 0; y < fieldNameList.size(); y++) {
					String labelName = rowSet.getMetaData().getColumnLabel(y + 1);
					//使用getObject获取原始类型 使用getString会把number类型转成string 造成问题
					Object fieldValue = rowSet.getObject(labelName);
					//这里只格式化标准的年月日时分秒格式2019-12-22 12:11:22（格式化.0后缀）
					if (MyUtils.isNotNull(fieldValue) && MyUtils.isDateTime(fieldValue)) {
						fieldValue = MyUtils.dateToStr(MyUtils.strToDate(fieldValue.toString()));
					}
					map.put(labelName, fieldValue);
				}
				resultList.add(map);
			}
		}	
		if (MyUtils.isNotNull(queryCountSQL) && MyUtils.isNotNull(page)) {
			Long count = myJdbcTemplate.queryForObject(queryCountSQL, Long.class);
			page.setTotalResult(count);
			page.setTotalPage(page.getTotalPage());
		}
		
		ResponseParams resp = new ResponseParams();
		resp.setExtra(resultList);
		resp.setPage(page);
		return resp;
	}

	public List<Map<String, Object>> queryForList(String sql) {
		return myJdbcTemplate.queryForList(sql);
	}	
 public Integer singleInsert(String sql) {
		KeyHolder keyHolder = new GeneratedKeyHolder();
		PreparedStatementCreator preparedStatementCreator = con -> {
			PreparedStatement ps = con.prepareStatement(sql, Statement.RETURN_GENERATED_KEYS);
			return ps;
		};
		myJdbcTemplate.update(preparedStatementCreator, keyHolder);
		return keyHolder.getKey().intValue();
	}
 public void executeSql(String sql) {
		myJdbcTemplate.execute(sql);
	}
	public Long queryForLongCount(String sql) {
		return myJdbcTemplate.queryForObject(sql, Long.class);
	}

	public Double queryForDoubleCount(String sql) {
		return myJdbcTemplate.queryForObject(sql, Double.class);
	}

	public Integer queryForIntegerCount(String sql) {
		return myJdbcTemplate.queryForObject(sql, Integer.class);
	}}
