package com.my.controller;

import java.io.File;
import java.io.FileInputStream;
import java.net.URLEncoder;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.util.FileCopyUtils;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import com.my.config.AccessInterceptor;
import com.my.model.ResponseParams;
import com.my.service.AccountService;
import com.my.service.FileService;

@RestController
@CrossOrigin("*")
public class ConsumerController {
	@Resource
	private AccountService accountService;
	@Resource
	private FileService fileService;
	
	@RequestMapping("/loginAccount")
	@AccessInterceptor
	public ResponseParams  loginAccount(
			@RequestParam("params") String params,
			HttpServletRequest request,HttpServletResponse response) {
		return accountService.loginAccount(params);
	}
	@RequestMapping("/loginAccountByToken")
	@AccessInterceptor
	public ResponseParams  loginAccountByToken(
			@RequestParam("token") String token) {
		return accountService.loginAccountByToken(token);
	}
	@RequestMapping("/saveAccount")
	public ResponseParams  saveAccount(
			@RequestParam("params") String params,
			@RequestParam(value="imgUrlf",required=false) MultipartFile imgUrlf,
			@RequestParam(value="companyLogof",required=false) MultipartFile companyLogof,
			HttpServletRequest request,HttpServletResponse response) {
		return accountService.saveAccount(params,imgUrlf,companyLogof);
	}
	@RequestMapping("/getMyAccount")
	public ResponseParams  getMyAccount(
			@RequestParam("params") String params,
			HttpServletRequest request,HttpServletResponse response) {
		return accountService.getMyAccount(params);
	}	
	
	@RequestMapping("/getFile/{fileId}")
	@AccessInterceptor
	public void getFile(
			@PathVariable("fileId") Integer fileId,
			HttpServletRequest request,HttpServletResponse response) {
		
		try {
			//（1）、直接打开即下载 根据fileId直接获取文件物理地址
			File f = fileService.getFile(fileId);
			if(f.exists()) {
				//（2）、下载或预览文件，以该图片形式【.jpg格式】直接打开预览（可先获取文件扩展名）
				response.setCharacterEncoding("UTF-8");// 设置编码
				response.addHeader("Content-Length", "" +  f.length());
				String expandName = f.getName().substring((f.getName().lastIndexOf(".") + 1));

				if(expandName.equals("xls")||expandName.equals("xlsx")){
					response.addHeader("Content-Disposition",
							"attachment;filename=" + URLEncoder.encode(f.getName(), "UTF-8"));
				}else {
					response.addHeader("Content-Type", "image/" + expandName);
				}
				FileInputStream in = new FileInputStream(f);
				FileCopyUtils.copy(in, response.getOutputStream());
			}
			
		} catch (Exception e) {
			
		}
	}
	

	/**
	 * 导出数据
	 * @param fileId
	 * @param request
	 * @param response
	 */
	@RequestMapping("/exportExcel")
	public void exportExcel(
			@PathVariable("fileId") Integer fileId,
			HttpServletRequest request,HttpServletResponse response) {
		
		try {
			//（1）、直接打开即下载 根据fileId直接获取文件物理地址
			File f = fileService.getFile(fileId);
			if(f.exists()) {
				//（2）、下载或预览文件，以该图片形式【.jpg格式】直接打开预览（可先获取文件扩展名）
				response.setCharacterEncoding("UTF-8");// 设置编码
				response.addHeader("Content-Length", "" +  f.length());
				String expandName = f.getName().substring((f.getName().lastIndexOf(".") + 1));

				response.addHeader("Content-Type", "image/" + expandName);
				FileInputStream in = new FileInputStream(f);
				FileCopyUtils.copy(in, response.getOutputStream());
			}
			
		} catch (Exception e) {
			
		}
	}
	

