package com.my.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import com.my.config.dbConfig.JdbcTemplateDao;
import com.my.model.AccountInfo;
import com.my.model.CommonException;
import com.my.model.LoginInfo;
import com.my.model.RequestParams;
import com.my.model.ResponseParams;
import com.my.service.AccountService;
import com.my.service.FileService;
import com.my.utils.MyUtils;

import net.sf.json.JSONObject;

@Service("accountService")
public class AccountServiceImpl implements AccountService{

	
	private static final String  login_table="simple_cloud_admin_account";
	
	@Resource
	private JdbcTemplateDao jdbcTemplateDao;
	
	@Resource
	private FileService fileService;
	
	@Override
	public LoginInfo doLoginAccount(Object userName,Object password) {
		if(!MyUtils.isNotNull(userName)) {
			throw new CommonException(-1, "用户名不能为空！！");
		}
		if(!MyUtils.isNotNull(password)) {
			throw new CommonException(-1, "密码不能为空！！");
		}
		String sql = "select id "
				+ " from "+login_table
				+ " where account_name =\""+userName+"\"";
		List<Map<String, Object>> mapList = jdbcTemplateDao.queryForList(sql);
		if(!MyUtils.isNotNull(mapList)) {
			throw new CommonException(-1, "用户名不存在！");
		}
		//1、密码加密
		String md5Password = MyUtils.getMd5Data(password.toString());
		sql = "select id,"
				+ " company_name companyName,"
				+ " company_logo companyLogo,"
				+ " img_url imgUrl,"
				+ " account_name accountName"
				+ " from "+login_table
				+ " where status =1 and id ="+Integer.valueOf(mapList.get(0).get("id").toString())
				+ " and password =\""+md5Password+"\"";
		mapList = jdbcTemplateDao.queryForList(sql);
		if(!MyUtils.isNotNull(mapList)) {
			throw new CommonException(-1, "密码错误！");
		}
		//2、生产token
		String accessToken = MyUtils.sign(mapList.get(0));
		
		//3、返回信息和token
		LoginInfo l=new LoginInfo();
		l.setAccessToken(accessToken);
		AccountInfo accountInfo = MyUtils.fromJson(MyUtils.toJson(mapList.get(0)), AccountInfo.class);
		l.setAccountInfo(accountInfo);
		return l;
	}
	/**
	 * 默认登录
	 * 返回token
	 * @param params
	 * @return
	 */
	@Override
	public ResponseParams loginAccount(String params) {
		JSONObject paramJson = JSONObject.fromObject(params);
		Object mobile= paramJson.opt("mobile");
		Object userName= paramJson.opt("userName");
		Object password= paramJson.opt("password");
		ResponseParams resp =new ResponseParams();
		resp.setExtra(doLoginAccount(userName, password));
		return resp;
	}
	
	/**
	 * 直接使用AccessToken登录
	 */
	@Override
	public ResponseParams loginAccountByToken(String accessToken) {
		ResponseParams resp =new ResponseParams();
		resp.setExtra(resolveAccount(accessToken));
		return resp;
	}
	/**
	 * 拦截请求
	 * 查询token里面的信息进行校验
	 * 比对
	 */
	@Override
	public AccountInfo resolveAccount(String token) {
		//1、解析、查询并比对，只比对id和accountName合法，可自行扩展修改
		String json = MyUtils.unsign(token);
		AccountInfo accountInfo = MyUtils.fromJson(json,AccountInfo.class);
		if(!MyUtils.isNotNull(accountInfo.getId())||
				!MyUtils.isNotNull(accountInfo.getAccountName())) {
			throw new CommonException(-1, "token非法");
		}
		String sql = "select account_name accountName"
				+ " from "+login_table
				+ " where id ="+accountInfo.getId();
		List<Map<String, Object>> mapList = jdbcTemplateDao.queryForList(sql);
		if(!MyUtils.isNotNull(mapList)) {
			throw new CommonException(-1, "token非法");
		}
		if(!mapList.get(0).get("accountName").toString().equals(accountInfo.getAccountName())) {
			throw new CommonException(-1, "token非法");
		}
		//2、比对成功，将参数放入回调参数
		return accountInfo;
	}
	
	/**
	 * 父子账号
	 * 获取所有父账号和子账号
	 */
	@Override
	public ResponseParams getMyAccount(String params) {
		RequestParams req = MyUtils.fromJson(params,RequestParams.class);

		String sql = "select id,mobile,"
				+ " company_name companyName,"
				+ " company_logo companyLogo,"
				+ " img_url imgUrl,"
				+ " account_name accountName"
				+ " from "+login_table
				+ " where status =1 "
				+ " and ( id ="+req.getAccountInfo().getId()
				+ " or parent_account_id="+req.getAccountInfo().getId()+")";
		ResponseParams resp =new ResponseParams();
		resp.setExtra( jdbcTemplateDao.queryForList(sql));
		return resp;
	}

	/**
	 * 新赠或保存
	 * 例子化
	 */
	@Override
	public ResponseParams saveAccount(String params,MultipartFile imgUrlf,MultipartFile companyLogof) {
		
		RequestParams req = MyUtils.fromJson(params,RequestParams.class);
		
		String sql0="";
		
		JSONObject JSON= MyUtils.fromJson(req.getEphemeralParam1());
		Object mobile =JSON.opt("mobile");
		if(!MyUtils.isNotNull(mobile)) {
			throw new CommonException(-1, "手机号不能为空！！");
		}
		Object account_name =JSON.opt("accountName");
		if(!MyUtils.isNotNull(account_name)) {
			throw new CommonException(-1, "账户名不能为空！！");
		}
		Object password =JSON.opt("password");
		String company_name =JSON.optString("companyName");
		String imgUrl="";
		String companyLogo="";
		if(MyUtils.isNotNull(imgUrlf)) {
			imgUrl  = fileService.uploadFile(
					req.getAccountInfo().getId(),imgUrlf);
		}
		if(MyUtils.isNotNull(companyLogof)) {
			companyLogo  = fileService.uploadFile(
					req.getAccountInfo().getId(),companyLogof);
		}
		if(MyUtils.isNotNull(req.getEphemeralParam())) {
			sql0 = " update "+ login_table +" set ";
			List<String> sb=new ArrayList<>();
			if(MyUtils.isNotNull(mobile)) {
				sb.add( "mobile="	 + MyUtils.addQuotation(mobile));
			}
			if(MyUtils.isNotNull(account_name)) {
				sb.add("account_name="	 + MyUtils.addQuotation(account_name));
			}
			if(MyUtils.isNotNull(company_name)) {
				sb.add("company_name="	 + MyUtils.addQuotation(company_name));
			}
			if(MyUtils.isNotNull(imgUrl)) {
				sb.add("img_url="	 + MyUtils.addQuotation(imgUrl));
			}
			if(MyUtils.isNotNull(companyLogo)) {
				sb.add("company_logo="	 + MyUtils.addQuotation(companyLogo));
			}
			if(MyUtils.isNotNull(password)) {
				password = MyUtils.getMd5Data(password.toString());
				sb.add("password="	 + MyUtils.addQuotation(password));
			}
			for (int i =0;i<sb.size();i++) {
				sql0+=sb.get(i);
				if(i!=sb.size()-1) {
					sql0+=",";
				}
			}
			sql0+=" where id ="	 +Integer.valueOf(req.getEphemeralParam().toString());
		}else {

			//新建的都是子账户
			if(!MyUtils.isNotNull(password)) {
				throw new CommonException(-1, "密码不能为空！！");
			}
			password = MyUtils.getMd5Data(password.toString());

			sql0 = " INSERT INTO "+login_table
					+" ("
					+" parent_account_id,mobile,account_name,company_name,img_url,password,company_logo,create_dtme ,status) "
					+" VALUES ("
					+ req.getAccountInfo().getId()+","
					+ MyUtils.addQuotation(mobile)+","
					+ MyUtils.addQuotation(account_name)+","
					+ MyUtils.addQuotation(company_name)+","
					+ MyUtils.addQuotation(imgUrl)+","
					+ MyUtils.addQuotation(password)+","
					+ MyUtils.addQuotation(companyLogo)+",now(),1)";
		}
		jdbcTemplateDao.executeSql(sql0);
		return new ResponseParams();
	}

	

}
